==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var UltimateOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.get_up = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_u2 = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/UltimateOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { UltimateOscillatorIndicatorCalculationStrategy } from "./UltimateOscillatorIndicatorCalculationStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var UltimateOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(UltimateOscillatorIndicator, _super);
    function UltimateOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    UltimateOscillatorIndicator.prototype.get_yy = function () {
        return new UltimateOscillatorIndicatorCalculationStrategy();
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.prototype.get_zb = function () {
        return UltimateOscillatorIndicator.$;
    };
    Object.defineProperty(UltimateOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    UltimateOscillatorIndicator.$t = markType(UltimateOscillatorIndicator, 'UltimateOscillatorIndicator', StrategyBasedIndicator.$);
    return UltimateOscillatorIndicator;
}(StrategyBasedIndicator));
export { UltimateOscillatorIndicator };
